@@ -68,12 +68,10 @@ def main() -> None:
 
     if opt.show_list:
         show_list_main()
-        sys.exit()
-    if opt.specified_time is not None:
+    elif opt.specified_time is not None:
         specified_time_main(opt, args)
-        sys.exit()
-
-    play_clock_main(opt, args)
+    else:
+        play_clock_main(opt, args)
 
 
 if __name__ == '__main__':
